Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(17)

Unified Diff: content/renderer/media/media_stream_audio_processor_options.h

Issue 1729683002: Remove old-style constraints from Chrome internals (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Complete the interface change Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/media/media_stream_audio_processor_options.h
diff --git a/content/renderer/media/media_stream_audio_processor_options.h b/content/renderer/media/media_stream_audio_processor_options.h
index 0d3be886ca91531add9668d0574181f86f6653c7..bb2a54e7c605d54e83cf5bf81d3e1168b8bb8050 100644
--- a/content/renderer/media/media_stream_audio_processor_options.h
+++ b/content/renderer/media/media_stream_audio_processor_options.h
@@ -13,12 +13,12 @@
#include "content/public/common/media_stream_request.h"
#include "third_party/WebKit/public/platform/WebMediaConstraints.h"
#include "third_party/webrtc/api/mediastreaminterface.h"
+#include "third_party/webrtc/media/base/mediachannel.h"
#include "third_party/webrtc/modules/audio_processing/include/audio_processing.h"
namespace webrtc {
class EchoCancellation;
-class MediaConstraintsInterface;
class TypingDetection;
}
@@ -28,7 +28,6 @@ namespace content {
class RTCMediaConstraints;
using webrtc::AudioProcessing;
-using webrtc::MediaConstraintsInterface;
// A helper class to parse audio constraints from a blink::WebMediaConstraints
// object.
@@ -48,11 +47,13 @@ class CONTENT_EXPORT MediaAudioConstraints {
static const char kGoogTypingNoiseDetection[];
static const char kGoogAudioMirroring[];
- // Merge |constraints| with |kDefaultAudioConstraints|. For any key which
- // exists in both, the value from |constraints| is maintained, including its
- // mandatory/optional status. New values from |kDefaultAudioConstraints| will
- // be added with optional status.
- static void ApplyFixedAudioConstraints(RTCMediaConstraints* constraints);
+ // Merge |options| with |kDefaultAudioConstraints|. For any key which
+ // exists in both, the value from |options| is maintained.
+ // New values from |kDefaultAudioConstraints| will
+ // be added.
+ // TODO(hta): Switch to an interface without "cricket::" when webrtc has one.
+
+ static void ApplyFixedAudioConstraints(cricket::AudioOptions* options);
// |effects| is the bitmasks telling whether certain platform
// hardware audio effects are enabled, like hardware echo cancellation. If
« no previous file with comments | « content/renderer/media/media_stream_audio_processor.cc ('k') | content/renderer/media/media_stream_audio_processor_options.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698